@@ -1,7 +1,8 @@
 # -*- shell-script -*-
 # "set different" debugger command
 #
-#   Copyright (C) 2011, 2014, 2016 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2011, 2014, 2016, 2019 Rocky Bernstein
+#   <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -32,7 +33,17 @@ _Dbg_complete_level_2_data[set_different]='on off'
 _Dbg_help_add_sub set different \
 '**set different** [**off**|**on**]
 
-Set to stop at a different line
+Set consecutive stops must be on different file/line positions.
+If no argument is given, different is set "off".
+
+One of the challenges of debugging is getting the granualarity of
+stepping comfortable. By setting different "on" you can set a more
+coarse-level of stepping which often still is small enough that you
+will not miss anything important.
+
+Note that the **step** and **next** debugger commands have **+** and
+**-** suffixes if you wan to override this setting on a per-command
+basis.
 
 See also:
 ---------
