@@ -1,7 +1,8 @@
 # -*- shell-script -*-
 # "set editing" debugger command
 #
-#   Copyright (C) 2010-2011, 2014 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2010-2011, 2014, 2019 Rocky Bernstein
+#   <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -30,7 +31,7 @@ typeset -A _Dbg_complete_level_2_data
 _Dbg_complete_level_2_data[set_editing]='emacs on off vi'
 
 _Dbg_help_add_sub set editing \
-'**set editing** [**on**|**off**]
+'**set editing** [ **on** | **off** | **emacs** | **vi** ]
 
 Readline editing of command lines
 
