@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # "show basename" debugger command
 #
-#   Copyright (C) 2014 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2014, 2019 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -18,20 +18,27 @@
 #   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
 #   MA 02111 USA.
 
-_Dbg_help_add_sub show basename \
-"show basename
+if [[ 0 == ${#funcfiletrace[@]} ]] ; then
+    dirname=${0%/*}
+    [[ $dirname == $0 ]] && top_dir='../..' || top_dir=${dirname}/../..
+    for lib_file in help alias ; do source $top_dir/lib/${lib_file}.sh; done
+    typeset -A _Dbg_command_help_show
+    typeset -A _Dbg_debugger_show_commands
+fi
 
-Show whether file basenames are in effect" 1
+_Dbg_help_add_sub show basename \
+'**show basename**
+
+Show whether file basenames are in effect.
+
+See also:
+---------
+
+**set basename**.' 1
 
 _Dbg_do_show_basename() {
-    typeset label="$1"
-    [[ -n $label ]] && label='basename:  '
-    _Dbg_msg_nocr \
-        "${label}Show short filenames is "
-    if (( _Dbg_set_basename == 0 )); then
-        _Dbg_msg 'off.'
-    else
-        _Dbg_msg 'on.'
-    fi
+    [[ -n $1 ]] && label=$(_Dbg_printf_nocr "%-12s: " basename)
+    _Dbg_msg \
+        "${label}Show short filenames (the basename) is " $(_Dbg_onoff $_Dbg_set_basename)
     return 0
 }
