@@ -1,7 +1,7 @@
 # -*- shell-script -*-
-# "show editing" debugger command
+# "show history" debugger command
 #
-#   Copyright (C) 2010 Rocky Bernstein rocky@gnu.org
+#   Copyright (C) 2010, 2014, 2019 Rocky Bernstein rocky@gnu.org
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -18,6 +18,12 @@
 #   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
 #   MA 02111 USA.
 
+_Dbg_help_add_sub show history \
+'**show history**
+
+Show history settings.
+' 1
+
 _Dbg_do_show_history() {
     _Dbg_msg \
         "filename: The filename in which to record the command history is:"
@@ -25,6 +31,6 @@ _Dbg_do_show_history() {
     _Dbg_msg \
         "save: Saving of history save is" $(_Dbg_onoff $_Dbg_set_history)
     _Dbg_msg \
-        "size: Debugger history size is $HISTSIZE, saving $SAVEHIST"
+        "size: Debugger history size is $_Dbg_history_size"
     return 0
 }
