@@ -12,7 +12,7 @@
 #   WARRANTY; without even the implied warranty of MERCHANTABILITY or
 #   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 #   for more details.
-#   
+#
 #   You should have received a copy of the GNU General Public License along
 #   with zshdb; see the file COPYING.  If not, write to the Free Software
 #   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
@@ -44,7 +44,7 @@ typeset -i _Dbg_script=0
 # This function is overwritten by when lib/fns.sh gets loaded
 _Dbg_msg()
 {
-  echo $*
+  echo "$*"
 }
 
 # Used by "show version" as well as --version
@@ -56,9 +56,9 @@ _Dbg_do_show_version()
 # Expand filename given as $1.
 # we echo the expanded name or return $1 unchanged if a bad filename.
 # Return is 0 if good or 1 if bad.
-# File globbing is handled. 
-# Note we don't check that the file exists, just that the format is 
-# valid; we do check that we can "search" the directory implied in the 
+# File globbing is handled.
+# Note we don't check that the file exists, just that the format is
+# valid; we do check that we can "search" the directory implied in the
 # filename.
 
 function _Dbg_expand_filename {
@@ -115,15 +115,14 @@ typeset -x _Dbg_init_cwd=$PWD
 
 typeset -i _Dbg_running=1      # True we are not finished running the program
 
-typeset -i _Dbg_brkpt_num=0    # If nonzero, the breakpoint number that we 
+typeset -i _Dbg_brkpt_num=0    # If nonzero, the breakpoint number that we
                                # are currently stopped at.
 
 # Sets whether or not to display command before executing it.
 typeset _Dbg_set_trace_commands='off'
 
 # Known normal IFS consisting of a space, tab and newline
-typeset -x _Dbg_space_IFS=' 	
-'
+typeset -x _Dbg_space_IFS=$' \t\r\n'
 
 # Number of statements to run before entering the debugger.  Is used
 # intially to get out of sourced dbg-main.inc script and in top-level
