@@ -1,6 +1,6 @@
 # -*- shell-script -*-
 #   Copyright (C) 2008-2009, 2011, 2014-2015, 2017
-#   Rocky Bernstein <rocky@gnu.org>
+#   2019 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -31,6 +31,12 @@ _Dbg_ansi_term_normal="[0m"
 typeset -g _Dbg_response=''
 
 _Dbg_confirm() {
+
+    if (( ! _Dbg_set_confirm )); then
+       _Dbg_response='y'
+       return 0
+    fi
+
     if (( $# < 1 || $# > 2 )) ; then
 	_Dbg_response='error'
 	return 0
@@ -38,18 +44,19 @@ _Dbg_confirm() {
     _Dbg_confirm_prompt=$1
     typeset _Dbg_confirm_default=${2:-'no'}
     while : ; do
-	  if [[ -t $_Dbg_fdi ]]; then
-	      vared -e -h -p "$_Dbg_confirm_prompt" _Dbg_response <&${_Dbg_fdi} || break
-	  else
-	      read "?$_Dbg_confirm_prompt" _Dbg_response <&${_Dbg_fdi} || break
-	  fi
+	_Dbg_response=''
+	if [[ -t $_Dbg_fdi ]]; then
+	    vared -e -h -p "$_Dbg_confirm_prompt" _Dbg_response <&${_Dbg_fdi} || break
+	else
+	    read "?$_Dbg_confirm_prompt" _Dbg_response <&${_Dbg_fdi} || break
+	fi
 
-	case "$_Dbg_response" in
+	case $_Dbg_response in
 	    'y' | 'yes' | 'yeah' | 'ya' | 'ja' | 'si' | 'oui' | 'ok' | 'okay' )
 		_Dbg_response='y'
 		return 0
 		;;
-	    'n' | 'no' | 'nope' | 'nyet' | 'nein' | 'non' )
+	    'N' | 'n' | 'no' | 'nope' | 'nyet' | 'nein' | 'non' )
 		_Dbg_response='n'
 		return 0
 		;;
